# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FunctionRpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from azure_functions_worker.protos.identity import ClaimsIdentityRpc_pb2 as identity_dot_ClaimsIdentityRpc__pb2
from azure_functions_worker.protos.shared import NullableTypes_pb2 as shared_dot_NullableTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='FunctionRpc.proto',
  package='AzureFunctionsRpcMessages',
  syntax='proto3',
  serialized_options=_b('\n*com.microsoft.azure.functions.rpc.messagesB\rFunctionProtoP\001Z7github.com/Azure/azure-functions-go-worker/internal/rpc\252\002,Microsoft.Azure.WebJobs.Script.Grpc.Messages'),
  serialized_pb=_b('\n\x11\x46unctionRpc.proto\x12\x19\x41zureFunctionsRpcMessages\x1a\x1egoogle/protobuf/duration.proto\x1a identity/ClaimsIdentityRpc.proto\x1a\x1ashared/NullableTypes.proto\"\x84\x0b\n\x10StreamingMessage\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12>\n\x0cstart_stream\x18\x14 \x01(\x0b\x32&.AzureFunctionsRpcMessages.StartStreamH\x00\x12K\n\x13worker_init_request\x18\x11 \x01(\x0b\x32,.AzureFunctionsRpcMessages.WorkerInitRequestH\x00\x12M\n\x14worker_init_response\x18\x10 \x01(\x0b\x32-.AzureFunctionsRpcMessages.WorkerInitResponseH\x00\x12\x46\n\x10worker_heartbeat\x18\x0f \x01(\x0b\x32*.AzureFunctionsRpcMessages.WorkerHeartbeatH\x00\x12\x46\n\x10worker_terminate\x18\x0e \x01(\x0b\x32*.AzureFunctionsRpcMessages.WorkerTerminateH\x00\x12O\n\x15worker_status_request\x18\x0c \x01(\x0b\x32..AzureFunctionsRpcMessages.WorkerStatusRequestH\x00\x12Q\n\x16worker_status_response\x18\r \x01(\x0b\x32/.AzureFunctionsRpcMessages.WorkerStatusResponseH\x00\x12V\n\x19\x66ile_change_event_request\x18\x06 \x01(\x0b\x32\x31.AzureFunctionsRpcMessages.FileChangeEventRequestH\x00\x12Q\n\x16worker_action_response\x18\x07 \x01(\x0b\x32/.AzureFunctionsRpcMessages.WorkerActionResponseH\x00\x12O\n\x15\x66unction_load_request\x18\x08 \x01(\x0b\x32..AzureFunctionsRpcMessages.FunctionLoadRequestH\x00\x12Q\n\x16\x66unction_load_response\x18\t \x01(\x0b\x32/.AzureFunctionsRpcMessages.FunctionLoadResponseH\x00\x12J\n\x12invocation_request\x18\x04 \x01(\x0b\x32,.AzureFunctionsRpcMessages.InvocationRequestH\x00\x12L\n\x13invocation_response\x18\x05 \x01(\x0b\x32-.AzureFunctionsRpcMessages.InvocationResponseH\x00\x12H\n\x11invocation_cancel\x18\x15 \x01(\x0b\x32+.AzureFunctionsRpcMessages.InvocationCancelH\x00\x12\x34\n\x07rpc_log\x18\x02 \x01(\x0b\x32!.AzureFunctionsRpcMessages.RpcLogH\x00\x12j\n#function_environment_reload_request\x18\x19 \x01(\x0b\x32;.AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequestH\x00\x12l\n$function_environment_reload_response\x18\x1a \x01(\x0b\x32<.AzureFunctionsRpcMessages.FunctionEnvironmentReloadResponseH\x00\x42\t\n\x07\x63ontent\" \n\x0bStartStream\x12\x11\n\tworker_id\x18\x02 \x01(\t\"\xec\x02\n\x11WorkerInitRequest\x12\x14\n\x0chost_version\x18\x01 \x01(\t\x12T\n\x0c\x63\x61pabilities\x18\x02 \x03(\x0b\x32>.AzureFunctionsRpcMessages.WorkerInitRequest.CapabilitiesEntry\x12W\n\x0elog_categories\x18\x03 \x03(\x0b\x32?.AzureFunctionsRpcMessages.WorkerInitRequest.LogCategoriesEntry\x1a\x33\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a]\n\x12LogCategoriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0e\x32\'.AzureFunctionsRpcMessages.RpcLog.Level:\x02\x38\x01\"\xf1\x01\n\x12WorkerInitResponse\x12\x16\n\x0eworker_version\x18\x01 \x01(\t\x12U\n\x0c\x63\x61pabilities\x18\x02 \x03(\x0b\x32?.AzureFunctionsRpcMessages.WorkerInitResponse.CapabilitiesEntry\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x1a\x33\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfe\x01\n\x0cStatusResult\x12>\n\x06status\x18\x04 \x01(\x0e\x32..AzureFunctionsRpcMessages.StatusResult.Status\x12\x0e\n\x06result\x18\x01 \x01(\t\x12:\n\texception\x18\x02 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.RpcException\x12/\n\x04logs\x18\x03 \x03(\x0b\x32!.AzureFunctionsRpcMessages.RpcLog\"1\n\x06Status\x12\x0b\n\x07\x46\x61ilure\x10\x00\x12\x0b\n\x07Success\x10\x01\x12\r\n\tCancelled\x10\x02\"\x11\n\x0fWorkerHeartbeat\"B\n\x0fWorkerTerminate\x12/\n\x0cgrace_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xd1\x01\n\x16\x46ileChangeEventRequest\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.AzureFunctionsRpcMessages.FileChangeEventRequest.Type\x12\x11\n\tfull_path\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"P\n\x04Type\x12\x0b\n\x07Unknown\x10\x00\x12\x0b\n\x07\x43reated\x10\x01\x12\x0b\n\x07\x44\x65leted\x10\x02\x12\x0b\n\x07\x43hanged\x10\x04\x12\x0b\n\x07Renamed\x10\x08\x12\x07\n\x03\x41ll\x10\x0f\"\x91\x01\n\x14WorkerActionResponse\x12\x46\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.AzureFunctionsRpcMessages.WorkerActionResponse.Action\x12\x0e\n\x06reason\x18\x02 \x01(\t\"!\n\x06\x41\x63tion\x12\x0b\n\x07Restart\x10\x00\x12\n\n\x06Reload\x10\x01\"\x15\n\x13WorkerStatusRequest\"\x16\n\x14WorkerStatusResponse\"\xf5\x01\n FunctionEnvironmentReloadRequest\x12t\n\x15\x65nvironment_variables\x18\x01 \x03(\x0b\x32U.AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry\x12\x1e\n\x16\x66unction_app_directory\x18\x02 \x01(\t\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n!FunctionEnvironmentReloadResponse\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\"\x90\x01\n\x13\x46unctionLoadRequest\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32..AzureFunctionsRpcMessages.RpcFunctionMetadata\x12\"\n\x1amanaged_dependency_enabled\x18\x03 \x01(\x08\"\x86\x01\n\x14\x46unctionLoadResponse\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12\x37\n\x06result\x18\x02 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x12 \n\x18is_dependency_downloaded\x18\x03 \x01(\x08\"\x9b\x02\n\x13RpcFunctionMetadata\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x13\n\x0bscript_file\x18\x02 \x01(\t\x12\x13\n\x0b\x65ntry_point\x18\x03 \x01(\t\x12N\n\x08\x62indings\x18\x06 \x03(\x0b\x32<.AzureFunctionsRpcMessages.RpcFunctionMetadata.BindingsEntry\x12\x10\n\x08is_proxy\x18\x07 \x01(\x08\x1aW\n\rBindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.AzureFunctionsRpcMessages.BindingInfo:\x02\x38\x01\"\xfe\x02\n\x11InvocationRequest\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66unction_id\x18\x02 \x01(\t\x12?\n\ninput_data\x18\x03 \x03(\x0b\x32+.AzureFunctionsRpcMessages.ParameterBinding\x12[\n\x10trigger_metadata\x18\x04 \x03(\x0b\x32\x41.AzureFunctionsRpcMessages.InvocationRequest.TriggerMetadataEntry\x12\x41\n\rtrace_context\x18\x05 \x01(\x0b\x32*.AzureFunctionsRpcMessages.RpcTraceContext\x1a\\\n\x14TriggerMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData:\x02\x38\x01\"\xbf\x01\n\x0fRpcTraceContext\x12\x14\n\x0ctrace_parent\x18\x01 \x01(\t\x12\x13\n\x0btrace_state\x18\x02 \x01(\t\x12N\n\nattributes\x18\x03 \x03(\x0b\x32:.AzureFunctionsRpcMessages.RpcTraceContext.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x10InvocationCancel\x12\x15\n\rinvocation_id\x18\x02 \x01(\t\x12/\n\x0cgrace_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xe2\x01\n\x12InvocationResponse\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12@\n\x0boutput_data\x18\x02 \x03(\x0b\x32+.AzureFunctionsRpcMessages.ParameterBinding\x12:\n\x0creturn_value\x18\x04 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\"\xd3\x03\n\tTypedData\x12\x10\n\x06string\x18\x01 \x01(\tH\x00\x12\x0e\n\x04json\x18\x02 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x03 \x01(\x0cH\x00\x12\x10\n\x06stream\x18\x04 \x01(\x0cH\x00\x12\x32\n\x04http\x18\x05 \x01(\x0b\x32\".AzureFunctionsRpcMessages.RpcHttpH\x00\x12\r\n\x03int\x18\x06 \x01(\x12H\x00\x12\x10\n\x06\x64ouble\x18\x07 \x01(\x01H\x00\x12\x46\n\x10\x63ollection_bytes\x18\x08 \x01(\x0b\x32*.AzureFunctionsRpcMessages.CollectionBytesH\x00\x12H\n\x11\x63ollection_string\x18\t \x01(\x0b\x32+.AzureFunctionsRpcMessages.CollectionStringH\x00\x12H\n\x11\x63ollection_double\x18\n \x01(\x0b\x32+.AzureFunctionsRpcMessages.CollectionDoubleH\x00\x12H\n\x11\x63ollection_sint64\x18\x0b \x01(\x0b\x32+.AzureFunctionsRpcMessages.CollectionSInt64H\x00\x42\x06\n\x04\x64\x61ta\"\"\n\x10\x43ollectionString\x12\x0e\n\x06string\x18\x01 \x03(\t\" \n\x0f\x43ollectionBytes\x12\r\n\x05\x62ytes\x18\x01 \x03(\x0c\"\"\n\x10\x43ollectionDouble\x12\x0e\n\x06\x64ouble\x18\x01 \x03(\x01\"\"\n\x10\x43ollectionSInt64\x12\x0e\n\x06sint64\x18\x01 \x03(\x12\"T\n\x10ParameterBinding\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\"\x8c\x02\n\x0b\x42indingInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x43\n\tdirection\x18\x03 \x01(\x0e\x32\x30.AzureFunctionsRpcMessages.BindingInfo.Direction\x12\x42\n\tdata_type\x18\x04 \x01(\x0e\x32/.AzureFunctionsRpcMessages.BindingInfo.DataType\"\'\n\tDirection\x12\x06\n\x02in\x10\x00\x12\x07\n\x03out\x10\x01\x12\t\n\x05inout\x10\x02\"=\n\x08\x44\x61taType\x12\r\n\tundefined\x10\x00\x12\n\n\x06string\x10\x01\x12\n\n\x06\x62inary\x10\x02\x12\n\n\x06stream\x10\x03\"\xac\x03\n\x06RpcLog\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x36\n\x05level\x18\x03 \x01(\x0e\x32\'.AzureFunctionsRpcMessages.RpcLog.Level\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12:\n\texception\x18\x06 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.RpcException\x12\x12\n\nproperties\x18\x07 \x01(\t\x12\x46\n\x0clog_category\x18\x08 \x01(\x0e\x32\x30.AzureFunctionsRpcMessages.RpcLog.RpcLogCategory\"^\n\x05Level\x12\t\n\x05Trace\x10\x00\x12\t\n\x05\x44\x65\x62ug\x10\x01\x12\x0f\n\x0bInformation\x10\x02\x12\x0b\n\x07Warning\x10\x03\x12\t\n\x05\x45rror\x10\x04\x12\x0c\n\x08\x43ritical\x10\x05\x12\x08\n\x04None\x10\x06\"&\n\x0eRpcLogCategory\x12\x08\n\x04User\x10\x00\x12\n\n\x06System\x10\x01\"D\n\x0cRpcException\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xe5\x02\n\rRpcHttpCookie\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x1f\n\x06\x64omain\x18\x03 \x01(\x0b\x32\x0f.NullableString\x12\x1d\n\x04path\x18\x04 \x01(\x0b\x32\x0f.NullableString\x12#\n\x07\x65xpires\x18\x05 \x01(\x0b\x32\x12.NullableTimestamp\x12\x1d\n\x06secure\x18\x06 \x01(\x0b\x32\r.NullableBool\x12 \n\thttp_only\x18\x07 \x01(\x0b\x32\r.NullableBool\x12\x44\n\tsame_site\x18\x08 \x01(\x0e\x32\x31.AzureFunctionsRpcMessages.RpcHttpCookie.SameSite\x12 \n\x07max_age\x18\t \x01(\x0b\x32\x0f.NullableDouble\")\n\x08SameSite\x12\x08\n\x04None\x10\x00\x12\x07\n\x03Lax\x10\x01\x12\n\n\x06Strict\x10\x02\"\xfa\x04\n\x07RpcHttp\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12@\n\x07headers\x18\x03 \x03(\x0b\x32/.AzureFunctionsRpcMessages.RpcHttp.HeadersEntry\x12\x32\n\x04\x62ody\x18\x04 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\x12>\n\x06params\x18\n \x03(\x0b\x32..AzureFunctionsRpcMessages.RpcHttp.ParamsEntry\x12\x13\n\x0bstatus_code\x18\x0c \x01(\t\x12<\n\x05query\x18\x0f \x03(\x0b\x32-.AzureFunctionsRpcMessages.RpcHttp.QueryEntry\x12\"\n\x1a\x65nable_content_negotiation\x18\x10 \x01(\x08\x12\x35\n\x07rawBody\x18\x11 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\x12&\n\nidentities\x18\x12 \x03(\x0b\x32\x12.RpcClaimsIdentity\x12\x39\n\x07\x63ookies\x18\x13 \x03(\x0b\x32(.AzureFunctionsRpcMessages.RpcHttpCookie\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32|\n\x0b\x46unctionRpc\x12m\n\x0b\x45ventStream\x12+.AzureFunctionsRpcMessages.StreamingMessage\x1a+.AzureFunctionsRpcMessages.StreamingMessage\"\x00(\x01\x30\x01\x42\xa5\x01\n*com.microsoft.azure.functions.rpc.messagesB\rFunctionProtoP\x01Z7github.com/Azure/azure-functions-go-worker/internal/rpc\xaa\x02,Microsoft.Azure.WebJobs.Script.Grpc.Messagesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,identity_dot_ClaimsIdentityRpc__pb2.DESCRIPTOR,shared_dot_NullableTypes__pb2.DESCRIPTOR,])



_STATUSRESULT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='AzureFunctionsRpcMessages.StatusResult.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Failure', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Success', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Cancelled', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2408,
  serialized_end=2457,
)
_sym_db.RegisterEnumDescriptor(_STATUSRESULT_STATUS)

_FILECHANGEEVENTREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='AzureFunctionsRpcMessages.FileChangeEventRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Created', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Deleted', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Changed', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Renamed', index=4, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='All', index=5, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2676,
  serialized_end=2756,
)
_sym_db.RegisterEnumDescriptor(_FILECHANGEEVENTREQUEST_TYPE)

_WORKERACTIONRESPONSE_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='AzureFunctionsRpcMessages.WorkerActionResponse.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Restart', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Reload', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2871,
  serialized_end=2904,
)
_sym_db.RegisterEnumDescriptor(_WORKERACTIONRESPONSE_ACTION)

_BINDINGINFO_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='AzureFunctionsRpcMessages.BindingInfo.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='in', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='out', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='inout', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5630,
  serialized_end=5669,
)
_sym_db.RegisterEnumDescriptor(_BINDINGINFO_DIRECTION)

_BINDINGINFO_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='AzureFunctionsRpcMessages.BindingInfo.DataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='undefined', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='string', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='binary', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stream', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5671,
  serialized_end=5732,
)
_sym_db.RegisterEnumDescriptor(_BINDINGINFO_DATATYPE)

_RPCLOG_LEVEL = _descriptor.EnumDescriptor(
  name='Level',
  full_name='AzureFunctionsRpcMessages.RpcLog.Level',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Trace', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Debug', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Information', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Warning', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Error', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Critical', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='None', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6029,
  serialized_end=6123,
)
_sym_db.RegisterEnumDescriptor(_RPCLOG_LEVEL)

_RPCLOG_RPCLOGCATEGORY = _descriptor.EnumDescriptor(
  name='RpcLogCategory',
  full_name='AzureFunctionsRpcMessages.RpcLog.RpcLogCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='User', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='System', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6125,
  serialized_end=6163,
)
_sym_db.RegisterEnumDescriptor(_RPCLOG_RPCLOGCATEGORY)

_RPCHTTPCOOKIE_SAMESITE = _descriptor.EnumDescriptor(
  name='SameSite',
  full_name='AzureFunctionsRpcMessages.RpcHttpCookie.SameSite',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Lax', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Strict', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6552,
  serialized_end=6593,
)
_sym_db.RegisterEnumDescriptor(_RPCHTTPCOOKIE_SAMESITE)


_STREAMINGMESSAGE = _descriptor.Descriptor(
  name='StreamingMessage',
  full_name='AzureFunctionsRpcMessages.StreamingMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='AzureFunctionsRpcMessages.StreamingMessage.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_stream', full_name='AzureFunctionsRpcMessages.StreamingMessage.start_stream', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_init_request', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_init_request', index=2,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_init_response', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_init_response', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_heartbeat', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_heartbeat', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_terminate', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_terminate', index=5,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_status_request', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_status_request', index=6,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_status_response', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_status_response', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_change_event_request', full_name='AzureFunctionsRpcMessages.StreamingMessage.file_change_event_request', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_action_response', full_name='AzureFunctionsRpcMessages.StreamingMessage.worker_action_response', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_load_request', full_name='AzureFunctionsRpcMessages.StreamingMessage.function_load_request', index=10,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_load_response', full_name='AzureFunctionsRpcMessages.StreamingMessage.function_load_response', index=11,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invocation_request', full_name='AzureFunctionsRpcMessages.StreamingMessage.invocation_request', index=12,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invocation_response', full_name='AzureFunctionsRpcMessages.StreamingMessage.invocation_response', index=13,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invocation_cancel', full_name='AzureFunctionsRpcMessages.StreamingMessage.invocation_cancel', index=14,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rpc_log', full_name='AzureFunctionsRpcMessages.StreamingMessage.rpc_log', index=15,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_environment_reload_request', full_name='AzureFunctionsRpcMessages.StreamingMessage.function_environment_reload_request', index=16,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_environment_reload_response', full_name='AzureFunctionsRpcMessages.StreamingMessage.function_environment_reload_response', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='AzureFunctionsRpcMessages.StreamingMessage.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=143,
  serialized_end=1555,
)


_STARTSTREAM = _descriptor.Descriptor(
  name='StartStream',
  full_name='AzureFunctionsRpcMessages.StartStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='AzureFunctionsRpcMessages.StartStream.worker_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1589,
)


_WORKERINITREQUEST_CAPABILITIESENTRY = _descriptor.Descriptor(
  name='CapabilitiesEntry',
  full_name='AzureFunctionsRpcMessages.WorkerInitRequest.CapabilitiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.CapabilitiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.CapabilitiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1810,
  serialized_end=1861,
)

_WORKERINITREQUEST_LOGCATEGORIESENTRY = _descriptor.Descriptor(
  name='LogCategoriesEntry',
  full_name='AzureFunctionsRpcMessages.WorkerInitRequest.LogCategoriesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.LogCategoriesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.LogCategoriesEntry.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1863,
  serialized_end=1956,
)

_WORKERINITREQUEST = _descriptor.Descriptor(
  name='WorkerInitRequest',
  full_name='AzureFunctionsRpcMessages.WorkerInitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_version', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.host_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.capabilities', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_categories', full_name='AzureFunctionsRpcMessages.WorkerInitRequest.log_categories', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WORKERINITREQUEST_CAPABILITIESENTRY, _WORKERINITREQUEST_LOGCATEGORIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1956,
)


_WORKERINITRESPONSE_CAPABILITIESENTRY = _descriptor.Descriptor(
  name='CapabilitiesEntry',
  full_name='AzureFunctionsRpcMessages.WorkerInitResponse.CapabilitiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.WorkerInitResponse.CapabilitiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.WorkerInitResponse.CapabilitiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1810,
  serialized_end=1861,
)

_WORKERINITRESPONSE = _descriptor.Descriptor(
  name='WorkerInitResponse',
  full_name='AzureFunctionsRpcMessages.WorkerInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_version', full_name='AzureFunctionsRpcMessages.WorkerInitResponse.worker_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='AzureFunctionsRpcMessages.WorkerInitResponse.capabilities', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='AzureFunctionsRpcMessages.WorkerInitResponse.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WORKERINITRESPONSE_CAPABILITIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1959,
  serialized_end=2200,
)


_STATUSRESULT = _descriptor.Descriptor(
  name='StatusResult',
  full_name='AzureFunctionsRpcMessages.StatusResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='AzureFunctionsRpcMessages.StatusResult.status', index=0,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='AzureFunctionsRpcMessages.StatusResult.result', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='AzureFunctionsRpcMessages.StatusResult.exception', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logs', full_name='AzureFunctionsRpcMessages.StatusResult.logs', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUSRESULT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2457,
)


_WORKERHEARTBEAT = _descriptor.Descriptor(
  name='WorkerHeartbeat',
  full_name='AzureFunctionsRpcMessages.WorkerHeartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2476,
)


_WORKERTERMINATE = _descriptor.Descriptor(
  name='WorkerTerminate',
  full_name='AzureFunctionsRpcMessages.WorkerTerminate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='grace_period', full_name='AzureFunctionsRpcMessages.WorkerTerminate.grace_period', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2478,
  serialized_end=2544,
)


_FILECHANGEEVENTREQUEST = _descriptor.Descriptor(
  name='FileChangeEventRequest',
  full_name='AzureFunctionsRpcMessages.FileChangeEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='AzureFunctionsRpcMessages.FileChangeEventRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_path', full_name='AzureFunctionsRpcMessages.FileChangeEventRequest.full_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='AzureFunctionsRpcMessages.FileChangeEventRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILECHANGEEVENTREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2547,
  serialized_end=2756,
)


_WORKERACTIONRESPONSE = _descriptor.Descriptor(
  name='WorkerActionResponse',
  full_name='AzureFunctionsRpcMessages.WorkerActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='AzureFunctionsRpcMessages.WorkerActionResponse.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='AzureFunctionsRpcMessages.WorkerActionResponse.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WORKERACTIONRESPONSE_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2759,
  serialized_end=2904,
)


_WORKERSTATUSREQUEST = _descriptor.Descriptor(
  name='WorkerStatusRequest',
  full_name='AzureFunctionsRpcMessages.WorkerStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2906,
  serialized_end=2927,
)


_WORKERSTATUSRESPONSE = _descriptor.Descriptor(
  name='WorkerStatusResponse',
  full_name='AzureFunctionsRpcMessages.WorkerStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2929,
  serialized_end=2951,
)


_FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY = _descriptor.Descriptor(
  name='EnvironmentVariablesEntry',
  full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3140,
  serialized_end=3199,
)

_FUNCTIONENVIRONMENTRELOADREQUEST = _descriptor.Descriptor(
  name='FunctionEnvironmentReloadRequest',
  full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='environment_variables', full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.environment_variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_app_directory', full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.function_app_directory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2954,
  serialized_end=3199,
)


_FUNCTIONENVIRONMENTRELOADRESPONSE = _descriptor.Descriptor(
  name='FunctionEnvironmentReloadResponse',
  full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='AzureFunctionsRpcMessages.FunctionEnvironmentReloadResponse.result', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3201,
  serialized_end=3293,
)


_FUNCTIONLOADREQUEST = _descriptor.Descriptor(
  name='FunctionLoadRequest',
  full_name='AzureFunctionsRpcMessages.FunctionLoadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_id', full_name='AzureFunctionsRpcMessages.FunctionLoadRequest.function_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='AzureFunctionsRpcMessages.FunctionLoadRequest.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='managed_dependency_enabled', full_name='AzureFunctionsRpcMessages.FunctionLoadRequest.managed_dependency_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3296,
  serialized_end=3440,
)


_FUNCTIONLOADRESPONSE = _descriptor.Descriptor(
  name='FunctionLoadResponse',
  full_name='AzureFunctionsRpcMessages.FunctionLoadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_id', full_name='AzureFunctionsRpcMessages.FunctionLoadResponse.function_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='AzureFunctionsRpcMessages.FunctionLoadResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_dependency_downloaded', full_name='AzureFunctionsRpcMessages.FunctionLoadResponse.is_dependency_downloaded', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3443,
  serialized_end=3577,
)


_RPCFUNCTIONMETADATA_BINDINGSENTRY = _descriptor.Descriptor(
  name='BindingsEntry',
  full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.BindingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.BindingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.BindingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3776,
  serialized_end=3863,
)

_RPCFUNCTIONMETADATA = _descriptor.Descriptor(
  name='RpcFunctionMetadata',
  full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.name', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='directory', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.directory', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script_file', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.script_file', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry_point', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.entry_point', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bindings', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.bindings', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_proxy', full_name='AzureFunctionsRpcMessages.RpcFunctionMetadata.is_proxy', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RPCFUNCTIONMETADATA_BINDINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3580,
  serialized_end=3863,
)


_INVOCATIONREQUEST_TRIGGERMETADATAENTRY = _descriptor.Descriptor(
  name='TriggerMetadataEntry',
  full_name='AzureFunctionsRpcMessages.InvocationRequest.TriggerMetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.InvocationRequest.TriggerMetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.InvocationRequest.TriggerMetadataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4156,
  serialized_end=4248,
)

_INVOCATIONREQUEST = _descriptor.Descriptor(
  name='InvocationRequest',
  full_name='AzureFunctionsRpcMessages.InvocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invocation_id', full_name='AzureFunctionsRpcMessages.InvocationRequest.invocation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_id', full_name='AzureFunctionsRpcMessages.InvocationRequest.function_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_data', full_name='AzureFunctionsRpcMessages.InvocationRequest.input_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trigger_metadata', full_name='AzureFunctionsRpcMessages.InvocationRequest.trigger_metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace_context', full_name='AzureFunctionsRpcMessages.InvocationRequest.trace_context', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOCATIONREQUEST_TRIGGERMETADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3866,
  serialized_end=4248,
)


_RPCTRACECONTEXT_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='AzureFunctionsRpcMessages.RpcTraceContext.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.RpcTraceContext.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.RpcTraceContext.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4393,
  serialized_end=4442,
)

_RPCTRACECONTEXT = _descriptor.Descriptor(
  name='RpcTraceContext',
  full_name='AzureFunctionsRpcMessages.RpcTraceContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_parent', full_name='AzureFunctionsRpcMessages.RpcTraceContext.trace_parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace_state', full_name='AzureFunctionsRpcMessages.RpcTraceContext.trace_state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='AzureFunctionsRpcMessages.RpcTraceContext.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RPCTRACECONTEXT_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4251,
  serialized_end=4442,
)


_INVOCATIONCANCEL = _descriptor.Descriptor(
  name='InvocationCancel',
  full_name='AzureFunctionsRpcMessages.InvocationCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invocation_id', full_name='AzureFunctionsRpcMessages.InvocationCancel.invocation_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grace_period', full_name='AzureFunctionsRpcMessages.InvocationCancel.grace_period', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4444,
  serialized_end=4534,
)


_INVOCATIONRESPONSE = _descriptor.Descriptor(
  name='InvocationResponse',
  full_name='AzureFunctionsRpcMessages.InvocationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invocation_id', full_name='AzureFunctionsRpcMessages.InvocationResponse.invocation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_data', full_name='AzureFunctionsRpcMessages.InvocationResponse.output_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='return_value', full_name='AzureFunctionsRpcMessages.InvocationResponse.return_value', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='AzureFunctionsRpcMessages.InvocationResponse.result', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4537,
  serialized_end=4763,
)


_TYPEDDATA = _descriptor.Descriptor(
  name='TypedData',
  full_name='AzureFunctionsRpcMessages.TypedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string', full_name='AzureFunctionsRpcMessages.TypedData.string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='json', full_name='AzureFunctionsRpcMessages.TypedData.json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='AzureFunctionsRpcMessages.TypedData.bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream', full_name='AzureFunctionsRpcMessages.TypedData.stream', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http', full_name='AzureFunctionsRpcMessages.TypedData.http', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int', full_name='AzureFunctionsRpcMessages.TypedData.int', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double', full_name='AzureFunctionsRpcMessages.TypedData.double', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_bytes', full_name='AzureFunctionsRpcMessages.TypedData.collection_bytes', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_string', full_name='AzureFunctionsRpcMessages.TypedData.collection_string', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_double', full_name='AzureFunctionsRpcMessages.TypedData.collection_double', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_sint64', full_name='AzureFunctionsRpcMessages.TypedData.collection_sint64', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='AzureFunctionsRpcMessages.TypedData.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4766,
  serialized_end=5233,
)


_COLLECTIONSTRING = _descriptor.Descriptor(
  name='CollectionString',
  full_name='AzureFunctionsRpcMessages.CollectionString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string', full_name='AzureFunctionsRpcMessages.CollectionString.string', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5235,
  serialized_end=5269,
)


_COLLECTIONBYTES = _descriptor.Descriptor(
  name='CollectionBytes',
  full_name='AzureFunctionsRpcMessages.CollectionBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes', full_name='AzureFunctionsRpcMessages.CollectionBytes.bytes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5271,
  serialized_end=5303,
)


_COLLECTIONDOUBLE = _descriptor.Descriptor(
  name='CollectionDouble',
  full_name='AzureFunctionsRpcMessages.CollectionDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='double', full_name='AzureFunctionsRpcMessages.CollectionDouble.double', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5305,
  serialized_end=5339,
)


_COLLECTIONSINT64 = _descriptor.Descriptor(
  name='CollectionSInt64',
  full_name='AzureFunctionsRpcMessages.CollectionSInt64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sint64', full_name='AzureFunctionsRpcMessages.CollectionSInt64.sint64', index=0,
      number=1, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5341,
  serialized_end=5375,
)


_PARAMETERBINDING = _descriptor.Descriptor(
  name='ParameterBinding',
  full_name='AzureFunctionsRpcMessages.ParameterBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='AzureFunctionsRpcMessages.ParameterBinding.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='AzureFunctionsRpcMessages.ParameterBinding.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5377,
  serialized_end=5461,
)


_BINDINGINFO = _descriptor.Descriptor(
  name='BindingInfo',
  full_name='AzureFunctionsRpcMessages.BindingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='AzureFunctionsRpcMessages.BindingInfo.type', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='AzureFunctionsRpcMessages.BindingInfo.direction', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='AzureFunctionsRpcMessages.BindingInfo.data_type', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BINDINGINFO_DIRECTION,
    _BINDINGINFO_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5464,
  serialized_end=5732,
)


_RPCLOG = _descriptor.Descriptor(
  name='RpcLog',
  full_name='AzureFunctionsRpcMessages.RpcLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invocation_id', full_name='AzureFunctionsRpcMessages.RpcLog.invocation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='AzureFunctionsRpcMessages.RpcLog.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='AzureFunctionsRpcMessages.RpcLog.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='AzureFunctionsRpcMessages.RpcLog.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='AzureFunctionsRpcMessages.RpcLog.event_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='AzureFunctionsRpcMessages.RpcLog.exception', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='AzureFunctionsRpcMessages.RpcLog.properties', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_category', full_name='AzureFunctionsRpcMessages.RpcLog.log_category', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RPCLOG_LEVEL,
    _RPCLOG_RPCLOGCATEGORY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5735,
  serialized_end=6163,
)


_RPCEXCEPTION = _descriptor.Descriptor(
  name='RpcException',
  full_name='AzureFunctionsRpcMessages.RpcException',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='AzureFunctionsRpcMessages.RpcException.source', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stack_trace', full_name='AzureFunctionsRpcMessages.RpcException.stack_trace', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='AzureFunctionsRpcMessages.RpcException.message', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6165,
  serialized_end=6233,
)


_RPCHTTPCOOKIE = _descriptor.Descriptor(
  name='RpcHttpCookie',
  full_name='AzureFunctionsRpcMessages.RpcHttpCookie',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.domain', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.path', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.expires', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secure', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.secure', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_only', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.http_only', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='same_site', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.same_site', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_age', full_name='AzureFunctionsRpcMessages.RpcHttpCookie.max_age', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RPCHTTPCOOKIE_SAMESITE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6236,
  serialized_end=6593,
)


_RPCHTTP_HEADERSENTRY = _descriptor.Descriptor(
  name='HeadersEntry',
  full_name='AzureFunctionsRpcMessages.RpcHttp.HeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.RpcHttp.HeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.RpcHttp.HeadersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7091,
  serialized_end=7137,
)

_RPCHTTP_PARAMSENTRY = _descriptor.Descriptor(
  name='ParamsEntry',
  full_name='AzureFunctionsRpcMessages.RpcHttp.ParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.RpcHttp.ParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.RpcHttp.ParamsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7139,
  serialized_end=7184,
)

_RPCHTTP_QUERYENTRY = _descriptor.Descriptor(
  name='QueryEntry',
  full_name='AzureFunctionsRpcMessages.RpcHttp.QueryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='AzureFunctionsRpcMessages.RpcHttp.QueryEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='AzureFunctionsRpcMessages.RpcHttp.QueryEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7186,
  serialized_end=7230,
)

_RPCHTTP = _descriptor.Descriptor(
  name='RpcHttp',
  full_name='AzureFunctionsRpcMessages.RpcHttp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='AzureFunctionsRpcMessages.RpcHttp.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='AzureFunctionsRpcMessages.RpcHttp.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headers', full_name='AzureFunctionsRpcMessages.RpcHttp.headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='AzureFunctionsRpcMessages.RpcHttp.body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='AzureFunctionsRpcMessages.RpcHttp.params', index=4,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='AzureFunctionsRpcMessages.RpcHttp.status_code', index=5,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='AzureFunctionsRpcMessages.RpcHttp.query', index=6,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_content_negotiation', full_name='AzureFunctionsRpcMessages.RpcHttp.enable_content_negotiation', index=7,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rawBody', full_name='AzureFunctionsRpcMessages.RpcHttp.rawBody', index=8,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identities', full_name='AzureFunctionsRpcMessages.RpcHttp.identities', index=9,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookies', full_name='AzureFunctionsRpcMessages.RpcHttp.cookies', index=10,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RPCHTTP_HEADERSENTRY, _RPCHTTP_PARAMSENTRY, _RPCHTTP_QUERYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6596,
  serialized_end=7230,
)

_STREAMINGMESSAGE.fields_by_name['start_stream'].message_type = _STARTSTREAM
_STREAMINGMESSAGE.fields_by_name['worker_init_request'].message_type = _WORKERINITREQUEST
_STREAMINGMESSAGE.fields_by_name['worker_init_response'].message_type = _WORKERINITRESPONSE
_STREAMINGMESSAGE.fields_by_name['worker_heartbeat'].message_type = _WORKERHEARTBEAT
_STREAMINGMESSAGE.fields_by_name['worker_terminate'].message_type = _WORKERTERMINATE
_STREAMINGMESSAGE.fields_by_name['worker_status_request'].message_type = _WORKERSTATUSREQUEST
_STREAMINGMESSAGE.fields_by_name['worker_status_response'].message_type = _WORKERSTATUSRESPONSE
_STREAMINGMESSAGE.fields_by_name['file_change_event_request'].message_type = _FILECHANGEEVENTREQUEST
_STREAMINGMESSAGE.fields_by_name['worker_action_response'].message_type = _WORKERACTIONRESPONSE
_STREAMINGMESSAGE.fields_by_name['function_load_request'].message_type = _FUNCTIONLOADREQUEST
_STREAMINGMESSAGE.fields_by_name['function_load_response'].message_type = _FUNCTIONLOADRESPONSE
_STREAMINGMESSAGE.fields_by_name['invocation_request'].message_type = _INVOCATIONREQUEST
_STREAMINGMESSAGE.fields_by_name['invocation_response'].message_type = _INVOCATIONRESPONSE
_STREAMINGMESSAGE.fields_by_name['invocation_cancel'].message_type = _INVOCATIONCANCEL
_STREAMINGMESSAGE.fields_by_name['rpc_log'].message_type = _RPCLOG
_STREAMINGMESSAGE.fields_by_name['function_environment_reload_request'].message_type = _FUNCTIONENVIRONMENTRELOADREQUEST
_STREAMINGMESSAGE.fields_by_name['function_environment_reload_response'].message_type = _FUNCTIONENVIRONMENTRELOADRESPONSE
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['start_stream'])
_STREAMINGMESSAGE.fields_by_name['start_stream'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_init_request'])
_STREAMINGMESSAGE.fields_by_name['worker_init_request'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_init_response'])
_STREAMINGMESSAGE.fields_by_name['worker_init_response'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_heartbeat'])
_STREAMINGMESSAGE.fields_by_name['worker_heartbeat'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_terminate'])
_STREAMINGMESSAGE.fields_by_name['worker_terminate'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_status_request'])
_STREAMINGMESSAGE.fields_by_name['worker_status_request'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_status_response'])
_STREAMINGMESSAGE.fields_by_name['worker_status_response'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['file_change_event_request'])
_STREAMINGMESSAGE.fields_by_name['file_change_event_request'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['worker_action_response'])
_STREAMINGMESSAGE.fields_by_name['worker_action_response'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['function_load_request'])
_STREAMINGMESSAGE.fields_by_name['function_load_request'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['function_load_response'])
_STREAMINGMESSAGE.fields_by_name['function_load_response'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['invocation_request'])
_STREAMINGMESSAGE.fields_by_name['invocation_request'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['invocation_response'])
_STREAMINGMESSAGE.fields_by_name['invocation_response'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['invocation_cancel'])
_STREAMINGMESSAGE.fields_by_name['invocation_cancel'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['rpc_log'])
_STREAMINGMESSAGE.fields_by_name['rpc_log'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['function_environment_reload_request'])
_STREAMINGMESSAGE.fields_by_name['function_environment_reload_request'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_STREAMINGMESSAGE.oneofs_by_name['content'].fields.append(
  _STREAMINGMESSAGE.fields_by_name['function_environment_reload_response'])
_STREAMINGMESSAGE.fields_by_name['function_environment_reload_response'].containing_oneof = _STREAMINGMESSAGE.oneofs_by_name['content']
_WORKERINITREQUEST_CAPABILITIESENTRY.containing_type = _WORKERINITREQUEST
_WORKERINITREQUEST_LOGCATEGORIESENTRY.fields_by_name['value'].enum_type = _RPCLOG_LEVEL
_WORKERINITREQUEST_LOGCATEGORIESENTRY.containing_type = _WORKERINITREQUEST
_WORKERINITREQUEST.fields_by_name['capabilities'].message_type = _WORKERINITREQUEST_CAPABILITIESENTRY
_WORKERINITREQUEST.fields_by_name['log_categories'].message_type = _WORKERINITREQUEST_LOGCATEGORIESENTRY
_WORKERINITRESPONSE_CAPABILITIESENTRY.containing_type = _WORKERINITRESPONSE
_WORKERINITRESPONSE.fields_by_name['capabilities'].message_type = _WORKERINITRESPONSE_CAPABILITIESENTRY
_WORKERINITRESPONSE.fields_by_name['result'].message_type = _STATUSRESULT
_STATUSRESULT.fields_by_name['status'].enum_type = _STATUSRESULT_STATUS
_STATUSRESULT.fields_by_name['exception'].message_type = _RPCEXCEPTION
_STATUSRESULT.fields_by_name['logs'].message_type = _RPCLOG
_STATUSRESULT_STATUS.containing_type = _STATUSRESULT
_WORKERTERMINATE.fields_by_name['grace_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FILECHANGEEVENTREQUEST.fields_by_name['type'].enum_type = _FILECHANGEEVENTREQUEST_TYPE
_FILECHANGEEVENTREQUEST_TYPE.containing_type = _FILECHANGEEVENTREQUEST
_WORKERACTIONRESPONSE.fields_by_name['action'].enum_type = _WORKERACTIONRESPONSE_ACTION
_WORKERACTIONRESPONSE_ACTION.containing_type = _WORKERACTIONRESPONSE
_FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY.containing_type = _FUNCTIONENVIRONMENTRELOADREQUEST
_FUNCTIONENVIRONMENTRELOADREQUEST.fields_by_name['environment_variables'].message_type = _FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY
_FUNCTIONENVIRONMENTRELOADRESPONSE.fields_by_name['result'].message_type = _STATUSRESULT
_FUNCTIONLOADREQUEST.fields_by_name['metadata'].message_type = _RPCFUNCTIONMETADATA
_FUNCTIONLOADRESPONSE.fields_by_name['result'].message_type = _STATUSRESULT
_RPCFUNCTIONMETADATA_BINDINGSENTRY.fields_by_name['value'].message_type = _BINDINGINFO
_RPCFUNCTIONMETADATA_BINDINGSENTRY.containing_type = _RPCFUNCTIONMETADATA
_RPCFUNCTIONMETADATA.fields_by_name['bindings'].message_type = _RPCFUNCTIONMETADATA_BINDINGSENTRY
_INVOCATIONREQUEST_TRIGGERMETADATAENTRY.fields_by_name['value'].message_type = _TYPEDDATA
_INVOCATIONREQUEST_TRIGGERMETADATAENTRY.containing_type = _INVOCATIONREQUEST
_INVOCATIONREQUEST.fields_by_name['input_data'].message_type = _PARAMETERBINDING
_INVOCATIONREQUEST.fields_by_name['trigger_metadata'].message_type = _INVOCATIONREQUEST_TRIGGERMETADATAENTRY
_INVOCATIONREQUEST.fields_by_name['trace_context'].message_type = _RPCTRACECONTEXT
_RPCTRACECONTEXT_ATTRIBUTESENTRY.containing_type = _RPCTRACECONTEXT
_RPCTRACECONTEXT.fields_by_name['attributes'].message_type = _RPCTRACECONTEXT_ATTRIBUTESENTRY
_INVOCATIONCANCEL.fields_by_name['grace_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INVOCATIONRESPONSE.fields_by_name['output_data'].message_type = _PARAMETERBINDING
_INVOCATIONRESPONSE.fields_by_name['return_value'].message_type = _TYPEDDATA
_INVOCATIONRESPONSE.fields_by_name['result'].message_type = _STATUSRESULT
_TYPEDDATA.fields_by_name['http'].message_type = _RPCHTTP
_TYPEDDATA.fields_by_name['collection_bytes'].message_type = _COLLECTIONBYTES
_TYPEDDATA.fields_by_name['collection_string'].message_type = _COLLECTIONSTRING
_TYPEDDATA.fields_by_name['collection_double'].message_type = _COLLECTIONDOUBLE
_TYPEDDATA.fields_by_name['collection_sint64'].message_type = _COLLECTIONSINT64
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['string'])
_TYPEDDATA.fields_by_name['string'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['json'])
_TYPEDDATA.fields_by_name['json'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['bytes'])
_TYPEDDATA.fields_by_name['bytes'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['stream'])
_TYPEDDATA.fields_by_name['stream'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['http'])
_TYPEDDATA.fields_by_name['http'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['int'])
_TYPEDDATA.fields_by_name['int'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['double'])
_TYPEDDATA.fields_by_name['double'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['collection_bytes'])
_TYPEDDATA.fields_by_name['collection_bytes'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['collection_string'])
_TYPEDDATA.fields_by_name['collection_string'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['collection_double'])
_TYPEDDATA.fields_by_name['collection_double'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_TYPEDDATA.oneofs_by_name['data'].fields.append(
  _TYPEDDATA.fields_by_name['collection_sint64'])
_TYPEDDATA.fields_by_name['collection_sint64'].containing_oneof = _TYPEDDATA.oneofs_by_name['data']
_PARAMETERBINDING.fields_by_name['data'].message_type = _TYPEDDATA
_BINDINGINFO.fields_by_name['direction'].enum_type = _BINDINGINFO_DIRECTION
_BINDINGINFO.fields_by_name['data_type'].enum_type = _BINDINGINFO_DATATYPE
_BINDINGINFO_DIRECTION.containing_type = _BINDINGINFO
_BINDINGINFO_DATATYPE.containing_type = _BINDINGINFO
_RPCLOG.fields_by_name['level'].enum_type = _RPCLOG_LEVEL
_RPCLOG.fields_by_name['exception'].message_type = _RPCEXCEPTION
_RPCLOG.fields_by_name['log_category'].enum_type = _RPCLOG_RPCLOGCATEGORY
_RPCLOG_LEVEL.containing_type = _RPCLOG
_RPCLOG_RPCLOGCATEGORY.containing_type = _RPCLOG
_RPCHTTPCOOKIE.fields_by_name['domain'].message_type = shared_dot_NullableTypes__pb2._NULLABLESTRING
_RPCHTTPCOOKIE.fields_by_name['path'].message_type = shared_dot_NullableTypes__pb2._NULLABLESTRING
_RPCHTTPCOOKIE.fields_by_name['expires'].message_type = shared_dot_NullableTypes__pb2._NULLABLETIMESTAMP
_RPCHTTPCOOKIE.fields_by_name['secure'].message_type = shared_dot_NullableTypes__pb2._NULLABLEBOOL
_RPCHTTPCOOKIE.fields_by_name['http_only'].message_type = shared_dot_NullableTypes__pb2._NULLABLEBOOL
_RPCHTTPCOOKIE.fields_by_name['same_site'].enum_type = _RPCHTTPCOOKIE_SAMESITE
_RPCHTTPCOOKIE.fields_by_name['max_age'].message_type = shared_dot_NullableTypes__pb2._NULLABLEDOUBLE
_RPCHTTPCOOKIE_SAMESITE.containing_type = _RPCHTTPCOOKIE
_RPCHTTP_HEADERSENTRY.containing_type = _RPCHTTP
_RPCHTTP_PARAMSENTRY.containing_type = _RPCHTTP
_RPCHTTP_QUERYENTRY.containing_type = _RPCHTTP
_RPCHTTP.fields_by_name['headers'].message_type = _RPCHTTP_HEADERSENTRY
_RPCHTTP.fields_by_name['body'].message_type = _TYPEDDATA
_RPCHTTP.fields_by_name['params'].message_type = _RPCHTTP_PARAMSENTRY
_RPCHTTP.fields_by_name['query'].message_type = _RPCHTTP_QUERYENTRY
_RPCHTTP.fields_by_name['rawBody'].message_type = _TYPEDDATA
_RPCHTTP.fields_by_name['identities'].message_type = identity_dot_ClaimsIdentityRpc__pb2._RPCCLAIMSIDENTITY
_RPCHTTP.fields_by_name['cookies'].message_type = _RPCHTTPCOOKIE
DESCRIPTOR.message_types_by_name['StreamingMessage'] = _STREAMINGMESSAGE
DESCRIPTOR.message_types_by_name['StartStream'] = _STARTSTREAM
DESCRIPTOR.message_types_by_name['WorkerInitRequest'] = _WORKERINITREQUEST
DESCRIPTOR.message_types_by_name['WorkerInitResponse'] = _WORKERINITRESPONSE
DESCRIPTOR.message_types_by_name['StatusResult'] = _STATUSRESULT
DESCRIPTOR.message_types_by_name['WorkerHeartbeat'] = _WORKERHEARTBEAT
DESCRIPTOR.message_types_by_name['WorkerTerminate'] = _WORKERTERMINATE
DESCRIPTOR.message_types_by_name['FileChangeEventRequest'] = _FILECHANGEEVENTREQUEST
DESCRIPTOR.message_types_by_name['WorkerActionResponse'] = _WORKERACTIONRESPONSE
DESCRIPTOR.message_types_by_name['WorkerStatusRequest'] = _WORKERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['WorkerStatusResponse'] = _WORKERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['FunctionEnvironmentReloadRequest'] = _FUNCTIONENVIRONMENTRELOADREQUEST
DESCRIPTOR.message_types_by_name['FunctionEnvironmentReloadResponse'] = _FUNCTIONENVIRONMENTRELOADRESPONSE
DESCRIPTOR.message_types_by_name['FunctionLoadRequest'] = _FUNCTIONLOADREQUEST
DESCRIPTOR.message_types_by_name['FunctionLoadResponse'] = _FUNCTIONLOADRESPONSE
DESCRIPTOR.message_types_by_name['RpcFunctionMetadata'] = _RPCFUNCTIONMETADATA
DESCRIPTOR.message_types_by_name['InvocationRequest'] = _INVOCATIONREQUEST
DESCRIPTOR.message_types_by_name['RpcTraceContext'] = _RPCTRACECONTEXT
DESCRIPTOR.message_types_by_name['InvocationCancel'] = _INVOCATIONCANCEL
DESCRIPTOR.message_types_by_name['InvocationResponse'] = _INVOCATIONRESPONSE
DESCRIPTOR.message_types_by_name['TypedData'] = _TYPEDDATA
DESCRIPTOR.message_types_by_name['CollectionString'] = _COLLECTIONSTRING
DESCRIPTOR.message_types_by_name['CollectionBytes'] = _COLLECTIONBYTES
DESCRIPTOR.message_types_by_name['CollectionDouble'] = _COLLECTIONDOUBLE
DESCRIPTOR.message_types_by_name['CollectionSInt64'] = _COLLECTIONSINT64
DESCRIPTOR.message_types_by_name['ParameterBinding'] = _PARAMETERBINDING
DESCRIPTOR.message_types_by_name['BindingInfo'] = _BINDINGINFO
DESCRIPTOR.message_types_by_name['RpcLog'] = _RPCLOG
DESCRIPTOR.message_types_by_name['RpcException'] = _RPCEXCEPTION
DESCRIPTOR.message_types_by_name['RpcHttpCookie'] = _RPCHTTPCOOKIE
DESCRIPTOR.message_types_by_name['RpcHttp'] = _RPCHTTP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamingMessage = _reflection.GeneratedProtocolMessageType('StreamingMessage', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGMESSAGE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.StreamingMessage)
  })
_sym_db.RegisterMessage(StreamingMessage)

StartStream = _reflection.GeneratedProtocolMessageType('StartStream', (_message.Message,), {
  'DESCRIPTOR' : _STARTSTREAM,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.StartStream)
  })
_sym_db.RegisterMessage(StartStream)

WorkerInitRequest = _reflection.GeneratedProtocolMessageType('WorkerInitRequest', (_message.Message,), {

  'CapabilitiesEntry' : _reflection.GeneratedProtocolMessageType('CapabilitiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKERINITREQUEST_CAPABILITIESENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerInitRequest.CapabilitiesEntry)
    })
  ,

  'LogCategoriesEntry' : _reflection.GeneratedProtocolMessageType('LogCategoriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKERINITREQUEST_LOGCATEGORIESENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerInitRequest.LogCategoriesEntry)
    })
  ,
  'DESCRIPTOR' : _WORKERINITREQUEST,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerInitRequest)
  })
_sym_db.RegisterMessage(WorkerInitRequest)
_sym_db.RegisterMessage(WorkerInitRequest.CapabilitiesEntry)
_sym_db.RegisterMessage(WorkerInitRequest.LogCategoriesEntry)

WorkerInitResponse = _reflection.GeneratedProtocolMessageType('WorkerInitResponse', (_message.Message,), {

  'CapabilitiesEntry' : _reflection.GeneratedProtocolMessageType('CapabilitiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKERINITRESPONSE_CAPABILITIESENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerInitResponse.CapabilitiesEntry)
    })
  ,
  'DESCRIPTOR' : _WORKERINITRESPONSE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerInitResponse)
  })
_sym_db.RegisterMessage(WorkerInitResponse)
_sym_db.RegisterMessage(WorkerInitResponse.CapabilitiesEntry)

StatusResult = _reflection.GeneratedProtocolMessageType('StatusResult', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRESULT,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.StatusResult)
  })
_sym_db.RegisterMessage(StatusResult)

WorkerHeartbeat = _reflection.GeneratedProtocolMessageType('WorkerHeartbeat', (_message.Message,), {
  'DESCRIPTOR' : _WORKERHEARTBEAT,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerHeartbeat)
  })
_sym_db.RegisterMessage(WorkerHeartbeat)

WorkerTerminate = _reflection.GeneratedProtocolMessageType('WorkerTerminate', (_message.Message,), {
  'DESCRIPTOR' : _WORKERTERMINATE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerTerminate)
  })
_sym_db.RegisterMessage(WorkerTerminate)

FileChangeEventRequest = _reflection.GeneratedProtocolMessageType('FileChangeEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILECHANGEEVENTREQUEST,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.FileChangeEventRequest)
  })
_sym_db.RegisterMessage(FileChangeEventRequest)

WorkerActionResponse = _reflection.GeneratedProtocolMessageType('WorkerActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKERACTIONRESPONSE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerActionResponse)
  })
_sym_db.RegisterMessage(WorkerActionResponse)

WorkerStatusRequest = _reflection.GeneratedProtocolMessageType('WorkerStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKERSTATUSREQUEST,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerStatusRequest)
  })
_sym_db.RegisterMessage(WorkerStatusRequest)

WorkerStatusResponse = _reflection.GeneratedProtocolMessageType('WorkerStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKERSTATUSRESPONSE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.WorkerStatusResponse)
  })
_sym_db.RegisterMessage(WorkerStatusResponse)

FunctionEnvironmentReloadRequest = _reflection.GeneratedProtocolMessageType('FunctionEnvironmentReloadRequest', (_message.Message,), {

  'EnvironmentVariablesEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentVariablesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry)
    })
  ,
  'DESCRIPTOR' : _FUNCTIONENVIRONMENTRELOADREQUEST,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest)
  })
_sym_db.RegisterMessage(FunctionEnvironmentReloadRequest)
_sym_db.RegisterMessage(FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry)

FunctionEnvironmentReloadResponse = _reflection.GeneratedProtocolMessageType('FunctionEnvironmentReloadResponse', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONENVIRONMENTRELOADRESPONSE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.FunctionEnvironmentReloadResponse)
  })
_sym_db.RegisterMessage(FunctionEnvironmentReloadResponse)

FunctionLoadRequest = _reflection.GeneratedProtocolMessageType('FunctionLoadRequest', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONLOADREQUEST,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.FunctionLoadRequest)
  })
_sym_db.RegisterMessage(FunctionLoadRequest)

FunctionLoadResponse = _reflection.GeneratedProtocolMessageType('FunctionLoadResponse', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONLOADRESPONSE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.FunctionLoadResponse)
  })
_sym_db.RegisterMessage(FunctionLoadResponse)

RpcFunctionMetadata = _reflection.GeneratedProtocolMessageType('RpcFunctionMetadata', (_message.Message,), {

  'BindingsEntry' : _reflection.GeneratedProtocolMessageType('BindingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCFUNCTIONMETADATA_BINDINGSENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcFunctionMetadata.BindingsEntry)
    })
  ,
  'DESCRIPTOR' : _RPCFUNCTIONMETADATA,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcFunctionMetadata)
  })
_sym_db.RegisterMessage(RpcFunctionMetadata)
_sym_db.RegisterMessage(RpcFunctionMetadata.BindingsEntry)

InvocationRequest = _reflection.GeneratedProtocolMessageType('InvocationRequest', (_message.Message,), {

  'TriggerMetadataEntry' : _reflection.GeneratedProtocolMessageType('TriggerMetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOCATIONREQUEST_TRIGGERMETADATAENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.InvocationRequest.TriggerMetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOCATIONREQUEST,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.InvocationRequest)
  })
_sym_db.RegisterMessage(InvocationRequest)
_sym_db.RegisterMessage(InvocationRequest.TriggerMetadataEntry)

RpcTraceContext = _reflection.GeneratedProtocolMessageType('RpcTraceContext', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCTRACECONTEXT_ATTRIBUTESENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcTraceContext.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _RPCTRACECONTEXT,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcTraceContext)
  })
_sym_db.RegisterMessage(RpcTraceContext)
_sym_db.RegisterMessage(RpcTraceContext.AttributesEntry)

InvocationCancel = _reflection.GeneratedProtocolMessageType('InvocationCancel', (_message.Message,), {
  'DESCRIPTOR' : _INVOCATIONCANCEL,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.InvocationCancel)
  })
_sym_db.RegisterMessage(InvocationCancel)

InvocationResponse = _reflection.GeneratedProtocolMessageType('InvocationResponse', (_message.Message,), {
  'DESCRIPTOR' : _INVOCATIONRESPONSE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.InvocationResponse)
  })
_sym_db.RegisterMessage(InvocationResponse)

TypedData = _reflection.GeneratedProtocolMessageType('TypedData', (_message.Message,), {
  'DESCRIPTOR' : _TYPEDDATA,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.TypedData)
  })
_sym_db.RegisterMessage(TypedData)

CollectionString = _reflection.GeneratedProtocolMessageType('CollectionString', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONSTRING,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.CollectionString)
  })
_sym_db.RegisterMessage(CollectionString)

CollectionBytes = _reflection.GeneratedProtocolMessageType('CollectionBytes', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONBYTES,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.CollectionBytes)
  })
_sym_db.RegisterMessage(CollectionBytes)

CollectionDouble = _reflection.GeneratedProtocolMessageType('CollectionDouble', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONDOUBLE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.CollectionDouble)
  })
_sym_db.RegisterMessage(CollectionDouble)

CollectionSInt64 = _reflection.GeneratedProtocolMessageType('CollectionSInt64', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONSINT64,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.CollectionSInt64)
  })
_sym_db.RegisterMessage(CollectionSInt64)

ParameterBinding = _reflection.GeneratedProtocolMessageType('ParameterBinding', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERBINDING,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.ParameterBinding)
  })
_sym_db.RegisterMessage(ParameterBinding)

BindingInfo = _reflection.GeneratedProtocolMessageType('BindingInfo', (_message.Message,), {
  'DESCRIPTOR' : _BINDINGINFO,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.BindingInfo)
  })
_sym_db.RegisterMessage(BindingInfo)

RpcLog = _reflection.GeneratedProtocolMessageType('RpcLog', (_message.Message,), {
  'DESCRIPTOR' : _RPCLOG,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcLog)
  })
_sym_db.RegisterMessage(RpcLog)

RpcException = _reflection.GeneratedProtocolMessageType('RpcException', (_message.Message,), {
  'DESCRIPTOR' : _RPCEXCEPTION,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcException)
  })
_sym_db.RegisterMessage(RpcException)

RpcHttpCookie = _reflection.GeneratedProtocolMessageType('RpcHttpCookie', (_message.Message,), {
  'DESCRIPTOR' : _RPCHTTPCOOKIE,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcHttpCookie)
  })
_sym_db.RegisterMessage(RpcHttpCookie)

RpcHttp = _reflection.GeneratedProtocolMessageType('RpcHttp', (_message.Message,), {

  'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCHTTP_HEADERSENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcHttp.HeadersEntry)
    })
  ,

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCHTTP_PARAMSENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcHttp.ParamsEntry)
    })
  ,

  'QueryEntry' : _reflection.GeneratedProtocolMessageType('QueryEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCHTTP_QUERYENTRY,
    '__module__' : 'FunctionRpc_pb2'
    # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcHttp.QueryEntry)
    })
  ,
  'DESCRIPTOR' : _RPCHTTP,
  '__module__' : 'FunctionRpc_pb2'
  # @@protoc_insertion_point(class_scope:AzureFunctionsRpcMessages.RpcHttp)
  })
_sym_db.RegisterMessage(RpcHttp)
_sym_db.RegisterMessage(RpcHttp.HeadersEntry)
_sym_db.RegisterMessage(RpcHttp.ParamsEntry)
_sym_db.RegisterMessage(RpcHttp.QueryEntry)


DESCRIPTOR._options = None
_WORKERINITREQUEST_CAPABILITIESENTRY._options = None
_WORKERINITREQUEST_LOGCATEGORIESENTRY._options = None
_WORKERINITRESPONSE_CAPABILITIESENTRY._options = None
_FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY._options = None
_RPCFUNCTIONMETADATA_BINDINGSENTRY._options = None
_INVOCATIONREQUEST_TRIGGERMETADATAENTRY._options = None
_RPCTRACECONTEXT_ATTRIBUTESENTRY._options = None
_RPCHTTP_HEADERSENTRY._options = None
_RPCHTTP_PARAMSENTRY._options = None
_RPCHTTP_QUERYENTRY._options = None

_FUNCTIONRPC = _descriptor.ServiceDescriptor(
  name='FunctionRpc',
  full_name='AzureFunctionsRpcMessages.FunctionRpc',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7232,
  serialized_end=7356,
  methods=[
  _descriptor.MethodDescriptor(
    name='EventStream',
    full_name='AzureFunctionsRpcMessages.FunctionRpc.EventStream',
    index=0,
    containing_service=None,
    input_type=_STREAMINGMESSAGE,
    output_type=_STREAMINGMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FUNCTIONRPC)

DESCRIPTOR.services_by_name['FunctionRpc'] = _FUNCTIONRPC

# @@protoc_insertion_point(module_scope)
